

local shape = {}

shape.create = function(x,y,radius,edges)
	local output = {}
		for i = 1,edges+1 do
			table.insert(output,radius*math.cos(((math.pi*2)/edges)*i) + x)
			table.insert(output,radius*math.sin(((math.pi*2)/edges)*i) + y)
		end
	return output
end

shape.move = function(x,y,t)
	local output = {}
	for i = 1,#t,2 do
			table.insert(output,t[i] + x)
			table.insert(output,t[i+1] + y)
	end
	return output
end

shape.rotate = function(center_x,center_y,radians,t)
	local output = {}
	for i = 1,#t,2 do
		table.insert(output,( ((t[i] - center_x) * math.cos(radians)) - ((t[i+1]-center_y) * math.sin(radians)) + center_x ))
		table.insert(output,( ((t[i] - center_x) * math.sin(radians)) + ((t[i+1] - center_y) * math.cos(radians)) + center_y ))
	end
	return output
end

shape.scale = function(t,center_x,center_y,multiplier)
	local output = {}
	for i = 1,#t,2 do
		table.insert(output,((t[i]-center_x)*multiplier)+center_x)
		table.insert(output,((t[i+1]-center_y)*multiplier)+center_y)
	end
	return output
end

shapes = {shape.create(0,0,500,5)}
shapes[1] = shape.rotate(0,0,math.rad(0),shapes[1])

number = 50

for i = 2,number do
	shapes[i] = shape.scale(shapes[i-1],0,0,0.9)
	shapes[i] = shape.rotate(0,0,math.rad(360/number),shapes[i])
end

for i = 1,#shapes do
	shapes[i] = shape.move(love.graphics.getWidth()/2,love.graphics.getHeight()/2,shapes[i])
end

spin = 5

function love.update(dt)
	--[[
	for i = 1,#shapes,2 do
		shapes[i] = shape.rotate(love.graphics.getWidth()/2,love.graphics.getHeight()/2,math.rad((spin*i)*dt),shapes[i])
		shapes[i+1] = shape.rotate(love.graphics.getWidth()/2,love.graphics.getHeight()/2,math.rad((spin*i)*dt)*-1,shapes[i+1])
	end]]
	for i = 1,#shapes do
		shapes[i] = shape.rotate(love.graphics.getWidth()/2,love.graphics.getHeight()/2,math.rad((spin*i)*dt),shapes[i])
	end
end

colornumber = 255/#shapes

function love.draw()
	for i,v in ipairs(shapes) do
		love.graphics.setColor(colornumber*i,colornumber*i/2,colornumber*i/2)
		love.graphics.polygon("fill",v)
		love.graphics.setColor(colornumber*i,colornumber*i,colornumber*i)
		love.graphics.polygon("line",v)
	end
end

function love.keypressed(k)
	if k == "escape" then
		love.event.push("quit")
	end
	if k == "f11" then
		love.graphics.toggleFullscreen()
	end
end